@@ -50,6 +50,11 @@
   structure(as.vector(x, mode = 'double') / 255, dim = dim(x))
 }
 
+#' @export
+"as.integer.magick-image" <- function(x, ...){
+  magick_image_write_integer(x)
+}
+
 #' @export
 "c.magick-image" <- function(...){
   image_join(...)
@@ -76,6 +81,18 @@
   lapply(seq_len(len), magick_image_subset, image = x)
 }
 
+#' @export
+"rep.magick-image" <- function(x, ...){
+  assert_image(x)
+  rep_magick_image(x, ...)
+}
+
+rep_magick_image <- function(x, times){
+  image_join(lapply(seq_len(times), function(...){
+    x
+  }))
+}
+
 #' @export
 "print.magick-image" <- function(x, info = TRUE, ...){
   img <- x
@@ -105,9 +122,7 @@
     invisible()
 }
 
-#' @export
-#' @method knit_print magick-image
-#' @importFrom knitr knit_print
+# This is registered as an S3 method in .onLoad()
 "knit_print.magick-image" <- function(x, ...){
   if(!length(x))
     return(invisible())
