@@ -1,4 +1,4 @@
-/* Jeroen Ooms (2017)
+/* Jeroen Ooms (2018)
  * Bindings to vectorized image manipulations.
  * See API: https://www.imagemagick.org/Magick++/STL.html
  */
@@ -152,13 +152,6 @@ XPtrImage magick_image_charcoal( XPtrImage input, const double radius = 1, const
   return output;
 }
 
-// [[Rcpp::export]]
-XPtrImage magick_image_edge( XPtrImage input, size_t radius){
-  XPtrImage output = copy(input);
-  for_each ( output->begin(), output->end(), Magick::edgeImage(radius));
-  return output;
-}
-
 /* Added in f78d1802df605fe2a0bd2551f4e4a27702e12828 */
 // [[Rcpp::export]]
 XPtrImage magick_image_deskew( XPtrImage input, double treshold){
